@@ -9,7 +9,6 @@ Module implementing the debug server.
 
 
 import os
-import sys
 
 from PyQt5.QtCore import pyqtSignal, QModelIndex
 from PyQt5.QtNetwork import (
@@ -188,7 +187,7 @@ class DebugServer(QTcpServer):
         
         self.networkInterface = Preferences.getDebugger("NetworkInterface")
         if self.networkInterface == "all":
-            hostAddress = QHostAddress("0.0.0.0")  # QHostAddress.Any)
+            hostAddress = QHostAddress("0.0.0.0")  # QHostAddress.Any)  # secok
         elif self.networkInterface == "allv6":
             hostAddress = QHostAddress("::")  # QHostAddress.AnyIPv6)
         else:
@@ -216,14 +215,6 @@ class DebugServer(QTcpServer):
         self.clientType = Preferences.Prefs.settings.value('DebugClient/Type')
         if self.clientType is None:
             self.clientType = 'Python3'
-        # Change clientType if dependent interpreter does not exist anymore
-        # (maybe deinstalled,...)
-        elif self.clientType == 'Python2' and Preferences.getDebugger(
-                "Python2VirtualEnv") == '' and sys.version_info[0] >= 3:
-            self.clientType = 'Python3'
-        elif self.clientType == 'Python3' and Preferences.getDebugger(
-                "Python3VirtualEnv") == '' and sys.version_info[0] == 2:
-            self.clientType = 'Python2'
         
         self.lastClientType = ''
         self.__autoClearShell = False
