@@ -174,7 +174,7 @@ class DebugUI(QObject):
         
         self.runAct = E5Action(
             self.tr('Run Script'),
-            UI.PixmapCache.getIcon("runScript.png"),
+            UI.PixmapCache.getIcon("runScript"),
             self.tr('&Run Script...'),
             Qt.Key_F2, 0, self, 'dbg_run_script')
         self.runAct.setStatusTip(self.tr('Run the current Script'))
@@ -189,7 +189,7 @@ class DebugUI(QObject):
 
         self.runProjectAct = E5Action(
             self.tr('Run Project'),
-            UI.PixmapCache.getIcon("runProject.png"),
+            UI.PixmapCache.getIcon("runProject"),
             self.tr('Run &Project...'), Qt.SHIFT + Qt.Key_F2, 0, self,
             'dbg_run_project')
         self.runProjectAct.setStatusTip(self.tr('Run the current Project'))
@@ -205,7 +205,7 @@ class DebugUI(QObject):
 
         self.coverageAct = E5Action(
             self.tr('Coverage run of Script'),
-            UI.PixmapCache.getIcon("coverageScript.png"),
+            UI.PixmapCache.getIcon("coverageScript"),
             self.tr('Coverage run of Script...'), 0, 0, self,
             'dbg_coverage_script')
         self.coverageAct.setStatusTip(
@@ -221,7 +221,7 @@ class DebugUI(QObject):
 
         self.coverageProjectAct = E5Action(
             self.tr('Coverage run of Project'),
-            UI.PixmapCache.getIcon("coverageProject.png"),
+            UI.PixmapCache.getIcon("coverageProject"),
             self.tr('Coverage run of Project...'), 0, 0, self,
             'dbg_coverage_project')
         self.coverageProjectAct.setStatusTip(
@@ -238,7 +238,7 @@ class DebugUI(QObject):
 
         self.profileAct = E5Action(
             self.tr('Profile Script'),
-            UI.PixmapCache.getIcon("profileScript.png"),
+            UI.PixmapCache.getIcon("profileScript"),
             self.tr('Profile Script...'), 0, 0, self, 'dbg_profile_script')
         self.profileAct.setStatusTip(self.tr('Profile the current Script'))
         self.profileAct.setWhatsThis(self.tr(
@@ -251,7 +251,7 @@ class DebugUI(QObject):
 
         self.profileProjectAct = E5Action(
             self.tr('Profile Project'),
-            UI.PixmapCache.getIcon("profileProject.png"),
+            UI.PixmapCache.getIcon("profileProject"),
             self.tr('Profile Project...'), 0, 0, self,
             'dbg_profile_project')
         self.profileProjectAct.setStatusTip(
@@ -267,7 +267,7 @@ class DebugUI(QObject):
 
         self.debugAct = E5Action(
             self.tr('Debug Script'),
-            UI.PixmapCache.getIcon("debugScript.png"),
+            UI.PixmapCache.getIcon("debugScript"),
             self.tr('&Debug Script...'), Qt.Key_F5, 0, self,
             'dbg_debug_script')
         self.debugAct.setStatusTip(self.tr('Debug the current Script'))
@@ -283,7 +283,7 @@ class DebugUI(QObject):
 
         self.debugProjectAct = E5Action(
             self.tr('Debug Project'),
-            UI.PixmapCache.getIcon("debugProject.png"),
+            UI.PixmapCache.getIcon("debugProject"),
             self.tr('Debug &Project...'), Qt.SHIFT + Qt.Key_F5, 0, self,
             'dbg_debug_project')
         self.debugProjectAct.setStatusTip(self.tr(
@@ -300,7 +300,7 @@ class DebugUI(QObject):
 
         self.restartAct = E5Action(
             self.tr('Restart'),
-            UI.PixmapCache.getIcon("debugRestart.png"),
+            UI.PixmapCache.getIcon("debugRestart"),
             self.tr('Restart'), Qt.Key_F4, 0, self, 'dbg_restart_script')
         self.restartAct.setStatusTip(self.tr(
             'Restart the last debugged script'))
@@ -316,7 +316,7 @@ class DebugUI(QObject):
 
         self.stopAct = E5Action(
             self.tr('Stop'),
-            UI.PixmapCache.getIcon("stopScript.png"),
+            UI.PixmapCache.getIcon("stopScript"),
             self.tr('Stop'), Qt.SHIFT + Qt.Key_F10, 0,
             self, 'dbg_stop_script')
         self.stopAct.setStatusTip(self.tr("""Stop the running script."""))
@@ -331,7 +331,7 @@ class DebugUI(QObject):
 
         act = E5Action(
             self.tr('Continue'),
-            UI.PixmapCache.getIcon("continue.png"),
+            UI.PixmapCache.getIcon("continue"),
             self.tr('&Continue'), Qt.Key_F6, 0,
             self.debugActGrp, 'dbg_continue')
         act.setStatusTip(
@@ -347,7 +347,7 @@ class DebugUI(QObject):
 
         act = E5Action(
             self.tr('Continue to Cursor'),
-            UI.PixmapCache.getIcon("continueToCursor.png"),
+            UI.PixmapCache.getIcon("continueToCursor"),
             self.tr('Continue &To Cursor'), Qt.SHIFT + Qt.Key_F6, 0,
             self.debugActGrp, 'dbg_continue_to_cursor')
         act.setStatusTip(self.tr(
@@ -363,7 +363,7 @@ class DebugUI(QObject):
         
         act = E5Action(
             self.tr('Move Instruction Pointer to Cursor'),
-            UI.PixmapCache.getIcon("moveInstructionPointer.png"),
+            UI.PixmapCache.getIcon("moveInstructionPointer"),
             self.tr('&Jump To Cursor'), Qt.Key_F12, 0,
             self.debugActGrp, 'dbg_jump_to_cursor')
         act.setStatusTip(self.tr(
@@ -383,7 +383,7 @@ class DebugUI(QObject):
 
         act = E5Action(
             self.tr('Single Step'),
-            UI.PixmapCache.getIcon("step.png"),
+            UI.PixmapCache.getIcon("step"),
             self.tr('Sin&gle Step'), Qt.Key_F7, 0,
             self.debugActGrp, 'dbg_single_step')
         act.setStatusTip(self.tr('Execute a single Python statement'))
@@ -399,7 +399,7 @@ class DebugUI(QObject):
 
         act = E5Action(
             self.tr('Step Over'),
-            UI.PixmapCache.getIcon("stepOver.png"),
+            UI.PixmapCache.getIcon("stepOver"),
             self.tr('Step &Over'), Qt.Key_F8, 0,
             self.debugActGrp, 'dbg_step_over')
         act.setStatusTip(self.tr(
@@ -418,7 +418,7 @@ class DebugUI(QObject):
 
         act = E5Action(
             self.tr('Step Out'),
-            UI.PixmapCache.getIcon("stepOut.png"),
+            UI.PixmapCache.getIcon("stepOut"),
             self.tr('Step Ou&t'), Qt.Key_F9, 0,
             self.debugActGrp, 'dbg_step_out')
         act.setStatusTip(self.tr(
@@ -437,7 +437,7 @@ class DebugUI(QObject):
 
         act = E5Action(
             self.tr('Stop'),
-            UI.PixmapCache.getIcon("stepQuit.png"),
+            UI.PixmapCache.getIcon("stepQuit"),
             self.tr('&Stop'), Qt.Key_F10, 0,
             self.debugActGrp, 'dbg_stop')
         act.setStatusTip(self.tr('Stop debugging'))
@@ -502,7 +502,7 @@ class DebugUI(QObject):
 
         self.dbgToggleBpAct = E5Action(
             self.tr('Toggle Breakpoint'),
-            UI.PixmapCache.getIcon("breakpointToggle.png"),
+            UI.PixmapCache.getIcon("breakpointToggle"),
             self.tr('Toggle Breakpoint'),
             QKeySequence(self.tr("Shift+F11", "Debug|Toggle Breakpoint")),
             0, self.dbgSetBpActGrp, 'dbg_toggle_breakpoint')
@@ -517,7 +517,7 @@ class DebugUI(QObject):
         
         self.dbgEditBpAct = E5Action(
             self.tr('Edit Breakpoint'),
-            UI.PixmapCache.getIcon("cBreakpointToggle.png"),
+            UI.PixmapCache.getIcon("cBreakpointToggle"),
             self.tr('Edit Breakpoint...'),
             QKeySequence(self.tr("Shift+F12", "Debug|Edit Breakpoint")), 0,
             self.dbgSetBpActGrp, 'dbg_edit_breakpoint')
@@ -532,7 +532,7 @@ class DebugUI(QObject):
 
         self.dbgNextBpAct = E5Action(
             self.tr('Next Breakpoint'),
-            UI.PixmapCache.getIcon("breakpointNext.png"),
+            UI.PixmapCache.getIcon("breakpointNext"),
             self.tr('Next Breakpoint'),
             QKeySequence(
                 self.tr("Ctrl+Shift+PgDown", "Debug|Next Breakpoint")), 0,
@@ -547,7 +547,7 @@ class DebugUI(QObject):
 
         self.dbgPrevBpAct = E5Action(
             self.tr('Previous Breakpoint'),
-            UI.PixmapCache.getIcon("breakpointPrevious.png"),
+            UI.PixmapCache.getIcon("breakpointPrevious"),
             self.tr('Previous Breakpoint'),
             QKeySequence(
                 self.tr("Ctrl+Shift+PgUp", "Debug|Previous Breakpoint")),
@@ -828,9 +828,7 @@ class DebugUI(QObject):
                     cap = self.debugServer.getClientCapabilities(language)
                     break
             else:
-                if editor.isPy2File():
-                    cap = self.debugServer.getClientCapabilities('Python2')
-                elif editor.isPy3File():
+                if editor.isPy3File():
                     cap = self.debugServer.getClientCapabilities('Python3')
                 elif editor.isRubyFile():
                     cap = self.debugServer.getClientCapabilities('Ruby')
@@ -1069,7 +1067,7 @@ class DebugUI(QObject):
                             os.path.basename(self.ui.currentProg), status,
                             info)
                     self.ui.showNotification(
-                        UI.PixmapCache.getPixmap("debug48.png"),
+                        UI.PixmapCache.getPixmap("debug48"),
                         self.tr("Program terminated"), msg)
                 else:
                     if self.ui.currentProg is None:
@@ -1397,7 +1395,7 @@ class DebugUI(QObject):
             cond, temp, enabled, count, special = dlg.getData()
             
             # check for duplicates
-            idx = self.__model.getWatchPointIndex(cond, special)
+            idx = model.getWatchPointIndex(cond, special)
             duplicate = (idx.isValid() and
                          idx.internalPointer() != index.internalPointer())
             if duplicate:
