@@ -13,8 +13,8 @@ import os
 import Globals
 
 SCOPES = 'https://www.googleapis.com/auth/gmail.send'
-CLIENT_SECRET_FILE = 'eric_client_secret.json'
-TOKEN_FILE = 'eric_python_email_send_token.json'
+CLIENT_SECRET_FILE = 'eric_client_secret.json'          # secok
+TOKEN_FILE = 'eric_python_email_send_token.json'        # secok
 APPLICATION_NAME = 'Eric Python Send Email'
 
 RequiredPackages = (
