@@ -12,8 +12,11 @@ from PyQt5.QtCore import QCoreApplication
 
 from Globals import translate
 
-__all__ = ["getTranslatedMessage"]
+from .Security.translations import (
+    _securityMessages, _securityMessagesSampleArgs
+)
 
+# TODO: separate this huge dict into separate translations per checker type
 _messages = {
     ##################################################################
     ## pycodestyle messages
@@ -302,9 +305,6 @@ _messages = {
     "D112": QCoreApplication.translate(
         "DocStyleChecker",
         'docstring containing \\ not surrounded by r"""'),
-    "D113": QCoreApplication.translate(
-        "DocStyleChecker",
-        'docstring containing unicode character not surrounded by u"""'),
     "D121": QCoreApplication.translate(
         "DocStyleChecker", "one-liner docstring on multiple lines"),
     "D122": QCoreApplication.translate(
@@ -854,151 +854,152 @@ _messages = {
     ##################################################################
     ## CodeStyleFixer messages
     ##################################################################
-    "FD111": QCoreApplication.translate(
+    
+    "FIXD111": QCoreApplication.translate(
         'CodeStyleFixer',
         "Triple single quotes converted to triple double quotes."),
-    'FD112': QCoreApplication.translate(
+    'FIXD112': QCoreApplication.translate(
         'CodeStyleFixer',
         'Introductory quotes corrected to be {0}"""'),
-    "FD121": QCoreApplication.translate(
+    "FIXD121": QCoreApplication.translate(
         'CodeStyleFixer',
         "Single line docstring put on one line."),
-    "FD131": QCoreApplication.translate(
+    "FIXD131": QCoreApplication.translate(
         'CodeStyleFixer',
         "Period added to summary line."),
-    "FD141": QCoreApplication.translate(
+    "FIXD141": QCoreApplication.translate(
         'CodeStyleFixer',
         "Blank line before function/method docstring removed."),
-    "FD142": QCoreApplication.translate(
+    "FIXD142": QCoreApplication.translate(
         'CodeStyleFixer',
         "Blank line inserted before class docstring."),
-    "FD143": QCoreApplication.translate(
+    "FIXD143": QCoreApplication.translate(
         'CodeStyleFixer',
         "Blank line inserted after class docstring."),
-    "FD144": QCoreApplication.translate(
+    "FIXD144": QCoreApplication.translate(
         'CodeStyleFixer',
         "Blank line inserted after docstring summary."),
-    "FD145": QCoreApplication.translate(
+    "FIXD145": QCoreApplication.translate(
         'CodeStyleFixer',
         "Blank line inserted after last paragraph of docstring."),
-    "FD221": QCoreApplication.translate(
+    "FIXD221": QCoreApplication.translate(
         'CodeStyleFixer',
         "Leading quotes put on separate line."),
-    "FD222": QCoreApplication.translate(
+    "FIXD222": QCoreApplication.translate(
         'CodeStyleFixer',
         "Trailing quotes put on separate line."),
-    "FD242": QCoreApplication.translate(
+    "FIXD242": QCoreApplication.translate(
         'CodeStyleFixer',
         "Blank line before class docstring removed."),
-    "FD244": QCoreApplication.translate(
+    "FIXD244": QCoreApplication.translate(
         'CodeStyleFixer',
         "Blank line before function/method docstring removed."),
-    "FD243": QCoreApplication.translate(
+    "FIXD243": QCoreApplication.translate(
         'CodeStyleFixer',
         "Blank line after class docstring removed."),
-    "FD245": QCoreApplication.translate(
+    "FIXD245": QCoreApplication.translate(
         'CodeStyleFixer',
         "Blank line after function/method docstring removed."),
-    "FD247": QCoreApplication.translate(
+    "FIXD247": QCoreApplication.translate(
         'CodeStyleFixer',
         "Blank line after last paragraph removed."),
-    "FE101": QCoreApplication.translate(
+    "FIXE101": QCoreApplication.translate(
         'CodeStyleFixer',
         "Tab converted to 4 spaces."),
-    "FE111": QCoreApplication.translate(
+    "FIXE111": QCoreApplication.translate(
         'CodeStyleFixer',
         "Indentation adjusted to be a multiple of four."),
-    "FE121": QCoreApplication.translate(
+    "FIXE121": QCoreApplication.translate(
         'CodeStyleFixer',
         "Indentation of continuation line corrected."),
-    "FE124": QCoreApplication.translate(
+    "FIXE124": QCoreApplication.translate(
         'CodeStyleFixer',
         "Indentation of closing bracket corrected."),
-    "FE122": QCoreApplication.translate(
+    "FIXE122": QCoreApplication.translate(
         'CodeStyleFixer',
         "Missing indentation of continuation line corrected."),
-    "FE123": QCoreApplication.translate(
+    "FIXE123": QCoreApplication.translate(
         'CodeStyleFixer',
         "Closing bracket aligned to opening bracket."),
-    "FE125": QCoreApplication.translate(
+    "FIXE125": QCoreApplication.translate(
         'CodeStyleFixer',
         "Indentation level changed."),
-    "FE126": QCoreApplication.translate(
+    "FIXE126": QCoreApplication.translate(
         'CodeStyleFixer',
         "Indentation level of hanging indentation changed."),
-    "FE127": QCoreApplication.translate(
+    "FIXE127": QCoreApplication.translate(
         'CodeStyleFixer',
         "Visual indentation corrected."),
-    "FE201": QCoreApplication.translate(
+    "FIXE201": QCoreApplication.translate(
         'CodeStyleFixer',
         "Extraneous whitespace removed."),
-    "FE225": QCoreApplication.translate(
+    "FIXE225": QCoreApplication.translate(
         'CodeStyleFixer',
         "Missing whitespace added."),
-    "FE221": QCoreApplication.translate(
+    "FIXE221": QCoreApplication.translate(
         'CodeStyleFixer',
         "Extraneous whitespace removed."),
-    "FE231": QCoreApplication.translate(
+    "FIXE231": QCoreApplication.translate(
         'CodeStyleFixer',
         "Missing whitespace added."),
-    "FE251": QCoreApplication.translate(
+    "FIXE251": QCoreApplication.translate(
         'CodeStyleFixer',
         "Extraneous whitespace removed."),
-    "FE261": QCoreApplication.translate(
+    "FIXE261": QCoreApplication.translate(
         'CodeStyleFixer',
         "Whitespace around comment sign corrected."),
     
-    "FE302+": lambda n=1: translate(
+    "FIXE302+": lambda n=1: translate(
         'CodeStyleFixer',
         "%n blank line(s) inserted.", '', n),
-    "FE302-": lambda n=1: translate(
+    "FIXE302-": lambda n=1: translate(
         'CodeStyleFixer',
         "%n superfluous lines removed", '', n),
     
-    "FE303": QCoreApplication.translate(
+    "FIXE303": QCoreApplication.translate(
         'CodeStyleFixer',
         "Superfluous blank lines removed."),
-    "FE304": QCoreApplication.translate(
+    "FIXE304": QCoreApplication.translate(
         'CodeStyleFixer',
         "Superfluous blank lines after function decorator removed."),
-    "FE401": QCoreApplication.translate(
+    "FIXE401": QCoreApplication.translate(
         'CodeStyleFixer',
         "Imports were put on separate lines."),
-    "FE501": QCoreApplication.translate(
+    "FIXE501": QCoreApplication.translate(
         'CodeStyleFixer',
         "Long lines have been shortened."),
-    "FE502": QCoreApplication.translate(
+    "FIXE502": QCoreApplication.translate(
         'CodeStyleFixer',
         "Redundant backslash in brackets removed."),
-    "FE701": QCoreApplication.translate(
+    "FIXE701": QCoreApplication.translate(
         'CodeStyleFixer',
         "Compound statement corrected."),
-    "FE702": QCoreApplication.translate(
+    "FIXE702": QCoreApplication.translate(
         'CodeStyleFixer',
         "Compound statement corrected."),
-    "FE711": QCoreApplication.translate(
+    "FIXE711": QCoreApplication.translate(
         'CodeStyleFixer',
         "Comparison to None/True/False corrected."),
-    "FN804": QCoreApplication.translate(
+    "FIXN804": QCoreApplication.translate(
         'CodeStyleFixer',
         "'{0}' argument added."),
-    "FN806": QCoreApplication.translate(
+    "FIXN806": QCoreApplication.translate(
         'CodeStyleFixer',
         "'{0}' argument removed."),
-    "FW291": QCoreApplication.translate(
+    "FIXW291": QCoreApplication.translate(
         'CodeStyleFixer',
         "Whitespace stripped from end of line."),
-    "FW292": QCoreApplication.translate(
+    "FIXW292": QCoreApplication.translate(
         'CodeStyleFixer',
         "newline added to end of file."),
-    "FW391": QCoreApplication.translate(
+    "FIXW391": QCoreApplication.translate(
         'CodeStyleFixer',
         "Superfluous trailing blank lines removed from end of file."),
-    "FW603": QCoreApplication.translate(
+    "FIXW603": QCoreApplication.translate(
         'CodeStyleFixer',
         "'<>' replaced by '!='."),
         
-    "FWRITE_ERROR": QCoreApplication.translate(
+    "FIXWRITE_ERROR": QCoreApplication.translate(
         'CodeStyleFixer',
         "Could not save the file! Skipping it. Reason: {0}"),
 }
@@ -1073,40 +1074,76 @@ _messages_sample_args = {
     "A891": [5, 3],
     "A999": ["SyntaxError", "Invalid Syntax"],
     
-    "FWRITE_ERROR": ["IOError"],
+    "FIXWRITE_ERROR": ["IOError"],
 }
 
+messageCatalogs = (
+    _messages,
+    _securityMessages,
+)
 
-def getTranslatedMessage(message):
+messageSampleArgsCatalog = (
+    _messages_sample_args,
+    _securityMessagesSampleArgs,
+)
+
+
+def getTranslatedMessage(messageCode, messageArgs, example=False):
     """
     Module function to get a translated and formatted message for a
-    given pyflakes message ID.
+    given message ID.
     
-    @param message the message ID (string)
-    @return translated and formatted message (string)
+    @param messageCode the message code
+    @type str
+    @param messageArgs list of arguments or a single integer value to format
+        the message
+    @type list or int
+    @param example flag indicating a translated message filled with example
+        data is requested (messageArgs is ignored if given)
+    @type bool
+    @return translated and formatted message
+    @rtype str
     """
-    if isinstance(message, list):
-        message, args = message
-    else:
-        args = []
-
-    if message in _messages:
-        if isinstance(args, int):
-            # Retranslate with correct plural form
-            return _messages[message](args)
+    if example:
+        for argsCatalog in messageSampleArgsCatalog:
+            if messageCode in argsCatalog:
+                args = argsCatalog[messageCode]
+                break
         else:
-            if message.startswith(('FD', 'FE', 'FN', 'FW')):
-                prefix = ''
-            else:
-                prefix = message + ' '
-            return prefix + _messages[message].format(*args)
-    elif ' ' in message:
-        # already translated
-        return message
+            args = None
     else:
-        return QCoreApplication.translate(
-            "CodeStyleFixer", " no message defined for code '{0}'"
-        ).format(message)
+        args = messageArgs
+    
+    for catalog in messageCatalogs:
+        if messageCode in catalog:
+            if args is None:
+                return catalog[messageCode]
+            elif isinstance(args, int):
+                # Retranslate with correct plural form
+                return catalog[messageCode](args)
+            else:
+                return catalog[messageCode].format(*args)
+    else:
+        if example:
+            return None
+        else:
+            return QCoreApplication.translate(
+                "CodeStyleChecker",
+                "No message defined for code '{0}'."
+            ).format(messageCode)
+
+
+def getMessageCodes():
+    """
+    Module function to get a list of known message codes.
+    
+    @return list of known message codes
+    @rtype set of str
+    """
+    knownCodes = []
+    for catalog in messageCatalogs:
+        knownCodes += list(catalog.keys())
+    return {c.split(".", 1)[0] for c in knownCodes}
 
 #
 # eflag: noqa = M201
