@@ -15,7 +15,7 @@ from PyQt5.QtCore import (
     pyqtSlot, Qt, QDate, QProcess, QTimer, QRegExp, QSize, QPoint, QFileInfo
 )
 from PyQt5.QtGui import (
-    QCursor, QColor, QPixmap, QPainter, QPen, QIcon, QTextCursor
+    QCursor, QColor, QPixmap, QPainter, QPen, QIcon, QTextCursor, QPalette
 )
 from PyQt5.QtWidgets import (
     QWidget, QDialogButtonBox, QHeaderView, QTreeWidgetItem, QApplication,
@@ -41,6 +41,11 @@ COLORNAMES = ["red", "green", "purple", "cyan", "olive", "magenta",
               "darkcyan", "darkmagenta", "blue"]
 COLORS = [str(QColor(x).name()) for x in COLORNAMES]
 
+LIGHTCOLORS = ["#aaaaff", "#7faa7f", "#ffaaaa", "#aaffaa", "#7f7faa",
+               "#ffaaff", "#aaffff", "#d5d579", "#ffaaff", "#d57979",
+               "#d579d5", "#79d5d5", "#d5d5d5", "#d5d500",
+               ]
+
 
 class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
     """
@@ -82,8 +87,8 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         self.filesTree.headerItem().setText(self.filesTree.columnCount(), "")
         self.filesTree.header().setSortIndicator(1, Qt.AscendingOrder)
         
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow.png"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow.png"))
+        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
         
         self.refreshButton = self.buttonBox.addButton(
             self.tr("&Refresh"), QDialogButtonBox.ActionRole)
@@ -91,8 +96,8 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             self.tr("Press to refresh the list of commits"))
         self.refreshButton.setEnabled(False)
         
-        self.findPrevButton.setIcon(UI.PixmapCache.getIcon("1leftarrow.png"))
-        self.findNextButton.setIcon(UI.PixmapCache.getIcon("1rightarrow.png"))
+        self.findPrevButton.setIcon(UI.PixmapCache.getIcon("1leftarrow"))
+        self.findNextButton.setIcon(UI.PixmapCache.getIcon("1rightarrow"))
         self.__findBackwards = False
         
         self.modeComboBox.addItem(self.tr("Find"), "find")
@@ -108,6 +113,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         self.__logTreeNormalFont.setBold(False)
         self.__logTreeBoldFont = self.logTree.font()
         self.__logTreeBoldFont.setBold(True)
+        self.__logTreeHasDarkBackground = e5App().usesDarkPalette()
         
         font = Preferences.getEditorOtherFonts("MonospacedFont")
         self.diffEdit.setFontFamily(font.family())
@@ -344,7 +350,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             "Show the most recent tag reachable from a commit"))
         
         self.actionsButton.setIcon(
-            UI.PixmapCache.getIcon("actionsToolButton.png"))
+            UI.PixmapCache.getIcon("actionsToolButton"))
         self.actionsButton.setMenu(self.__actionsMenu)
     
     def __initData(self):
@@ -469,10 +475,15 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         """
         Private method to get the (rotating) name of the color given an index.
         
-        @param n color index (integer)
-        @return color name (string)
+        @param n color index
+        @type int
+        @return color name
+        @rtype str
         """
-        return COLORS[n % len(COLORS)]
+        if self.__logTreeHasDarkBackground:
+            return LIGHTCOLORS[n % len(LIGHTCOLORS)]
+        else:
+            return COLORS[n % len(COLORS)]
     
     def __generateEdges(self, commitId, parents):
         """
@@ -558,25 +569,16 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         dot_y = h // 2
         
         pix = QPixmap(w, h)
-        pix.fill(QColor(0, 0, 0, 0))
+        pix.fill(QColor(0, 0, 0, 0))        # draw transparent background
         painter = QPainter(pix)
         painter.setRenderHint(QPainter.Antialiasing)
         
-        pen = QPen(Qt.blue)
-        pen.setWidth(2)
-        painter.setPen(pen)
-        
-        lpen = QPen(pen)
-        lpen.setColor(Qt.black)
-        painter.setPen(lpen)
-        
         # draw the revision history lines
         for y1, y2, lines in ((0, h, bottomedges),
                               (-h, 0, topedges)):
             if lines:
                 for start, end, ecolor in lines:
-                    lpen = QPen(pen)
-                    lpen.setColor(QColor(self.__getColor(ecolor)))
+                    lpen = QPen(QColor(self.__getColor(ecolor)))
                     lpen.setWidth(2)
                     painter.setPen(lpen)
                     x1 = col2x(start, radius)
@@ -584,7 +586,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
                     painter.drawLine(x1, dot_y + y1, x2, dot_y + y2)
         
         penradius = 1
-        pencolor = Qt.black
+        pencolor = self.logTree.palette().color(QPalette.Text)
         
         dot_y = (h // 2) - radius // 2
         
