@@ -204,7 +204,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.png")),
+                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -212,28 +212,28 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
         
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('Update from repository'), self._VCSUpdate)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr('Add to repository'),
             self._VCSAdd)
         self.vcsAddMenuActions.append(act)
         if 1 in self.browser.specialMenuEntries:
             self.vcsMenuAddTree = menu.addAction(
-                UI.PixmapCache.getIcon("vcsAdd.png"),
+                UI.PixmapCache.getIcon("vcsAdd"),
                 self.tr('Add tree to repository'),
                 self._VCSAddTree)
             self.vcsAddMenuActions.append(self.vcsMenuAddTree)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsMenuActions.append(act)
@@ -255,39 +255,39 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLog.png"),
+            UI.PixmapCache.getIcon("vcsLog"),
             self.tr('Show log browser'), self._VCSLogBrowser)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show status'), self._VCSStatus)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRepo.png"),
+            UI.PixmapCache.getIcon("vcsRepo"),
             self.tr('Show repository info'), self.__SVNInfo)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences'), self._VCSDiff)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff.png"),
+            UI.PixmapCache.getIcon("vcsSbsDiff"),
             self.tr('Show differences side-by-side'), self.__SVNSbsDiff)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended)'),
             self.__SVNExtendedDiff)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff.png"),
+            UI.PixmapCache.getIcon("vcsSbsDiff"),
             self.tr('Show differences side-by-side (extended)'),
             self.__SVNSbsExtendedDiff)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (URLs)'),
             self.__SVNUrlDiff)
         self.vcsMenuActions.append(act)
@@ -297,11 +297,11 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMenuActions.append(self.blameAct)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Revert changes'), self._VCSRevert)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsMerge.png"),
+            UI.PixmapCache.getIcon("vcsMerge"),
             self.tr('Merge changes'), self._VCSMerge)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
@@ -309,19 +309,19 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLock.png"),
+            UI.PixmapCache.getIcon("vcsLock"),
             self.tr('Lock'), self.__SVNLock)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock.png"),
+            UI.PixmapCache.getIcon("vcsUnlock"),
             self.tr('Unlock'), self.__SVNUnlock)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock.png"),
+            UI.PixmapCache.getIcon("vcsUnlock"),
             self.tr('Break Lock'), self.__SVNBreakLock)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock.png"),
+            UI.PixmapCache.getIcon("vcsUnlock"),
             self.tr('Steal Lock'), self.__SVNStealLock)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
@@ -362,7 +362,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.png")),
+                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -370,26 +370,26 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
         
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('Update from repository'), self._VCSUpdate)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr('Add to repository'), self._VCSAdd)
         self.vcsAddMultiMenuActions.append(act)
         if 1 in self.browser.specialMenuEntries:
             self.vcsMultiMenuAddTree = menu.addAction(
-                UI.PixmapCache.getIcon("vcsAdd.png"),
+                UI.PixmapCache.getIcon("vcsAdd"),
                 self.tr('Add tree to repository'), self._VCSAddTree)
             self.vcsAddMultiMenuActions.append(self.vcsMultiMenuAddTree)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsMultiMenuActions.append(act)
@@ -405,27 +405,27 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show status'), self._VCSStatus)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences'), self._VCSDiff)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended)'),
             self.__SVNExtendedDiff)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (URLs)'),
             self.__SVNUrlDiff)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Revert changes'), self._VCSRevert)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
@@ -433,19 +433,19 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLock.png"),
+            UI.PixmapCache.getIcon("vcsLock"),
             self.tr('Lock'), self.__SVNLock)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock.png"),
+            UI.PixmapCache.getIcon("vcsUnlock"),
             self.tr('Unlock'), self.__SVNUnlock)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock.png"),
+            UI.PixmapCache.getIcon("vcsUnlock"),
             self.tr('Break Lock'), self.__SVNBreakLock)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUnlock.png"),
+            UI.PixmapCache.getIcon("vcsUnlock"),
             self.tr('Steal Lock'), self.__SVNStealLock)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
@@ -482,7 +482,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.png")),
+                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -520,7 +520,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.png")),
+                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -528,21 +528,21 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
         
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('Update from repository'), self._VCSUpdate)
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr('Add to repository'), self._VCSAdd)
         self.vcsAddDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsDirMenuActions.append(act)
@@ -563,40 +563,40 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLog.png"),
+            UI.PixmapCache.getIcon("vcsLog"),
             self.tr('Show log browser'), self._VCSLogBrowser)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show status'), self._VCSStatus)
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRepo.png"),
+            UI.PixmapCache.getIcon("vcsRepo"),
             self.tr('Show repository info'), self.__SVNInfo)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences'), self._VCSDiff)
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended)'),
             self.__SVNExtendedDiff)
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (URLs)'),
             self.__SVNUrlDiff)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Revert changes'), self._VCSRevert)
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsMerge.png"),
+            UI.PixmapCache.getIcon("vcsMerge"),
             self.tr('Merge changes'), self._VCSMerge)
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
@@ -642,7 +642,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.png")),
+                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -650,21 +650,21 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
         
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('Update from repository'), self._VCSUpdate)
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr('Add to repository'), self._VCSAdd)
         self.vcsAddDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsDirMultiMenuActions.append(act)
@@ -680,31 +680,31 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show status'), self._VCSStatus)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences'), self._VCSDiff)
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended)'),
             self.__SVNExtendedDiff)
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (URLs)'),
             self.__SVNUrlDiff)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Revert changes'), self._VCSRevert)
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsMerge.png"),
+            UI.PixmapCache.getIcon("vcsMerge"),
             self.tr('Merge changes'), self._VCSMerge)
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
@@ -760,13 +760,15 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             fn = itm.dirName()
         isFile = os.path.isfile(fn)
         movefiles = self.browser.project.getFiles(fn)
+        self.browser.project.stopFileSystemMonitoring()
         if self.vcs.vcsMove(fn, self.project):
             if isFile:
                 self.browser.closeSourceWindow.emit(fn)
             else:
                 for mf in movefiles:
                     self.browser.closeSourceWindow.emit(mf)
-        
+        self.browser.project.startFileSystemMonitoring()
+    
     def __SVNResolve(self):
         """
         Private slot called by the context menu to resolve conflicts of a file.
