@@ -49,34 +49,34 @@ class QRegularExpressionWizardWidget(QWidget,
         self.setupUi(self)
         
         # initialize icons of the tool buttons
-        self.commentButton.setIcon(UI.PixmapCache.getIcon("comment.png"))
-        self.charButton.setIcon(UI.PixmapCache.getIcon("characters.png"))
-        self.anycharButton.setIcon(UI.PixmapCache.getIcon("anychar.png"))
-        self.repeatButton.setIcon(UI.PixmapCache.getIcon("repeat.png"))
-        self.nonGroupButton.setIcon(UI.PixmapCache.getIcon("nongroup.png"))
+        self.commentButton.setIcon(UI.PixmapCache.getIcon("comment"))
+        self.charButton.setIcon(UI.PixmapCache.getIcon("characters"))
+        self.anycharButton.setIcon(UI.PixmapCache.getIcon("anychar"))
+        self.repeatButton.setIcon(UI.PixmapCache.getIcon("repeat"))
+        self.nonGroupButton.setIcon(UI.PixmapCache.getIcon("nongroup"))
         self.atomicGroupButton.setIcon(
-            UI.PixmapCache.getIcon("atomicgroup.png"))
-        self.groupButton.setIcon(UI.PixmapCache.getIcon("group.png"))
-        self.namedGroupButton.setIcon(UI.PixmapCache.getIcon("namedgroup.png"))
+            UI.PixmapCache.getIcon("atomicgroup"))
+        self.groupButton.setIcon(UI.PixmapCache.getIcon("group"))
+        self.namedGroupButton.setIcon(UI.PixmapCache.getIcon("namedgroup"))
         self.namedReferenceButton.setIcon(
-            UI.PixmapCache.getIcon("namedreference.png"))
-        self.altnButton.setIcon(UI.PixmapCache.getIcon("altn.png"))
-        self.beglineButton.setIcon(UI.PixmapCache.getIcon("begline.png"))
-        self.endlineButton.setIcon(UI.PixmapCache.getIcon("endline.png"))
+            UI.PixmapCache.getIcon("namedreference"))
+        self.altnButton.setIcon(UI.PixmapCache.getIcon("altn"))
+        self.beglineButton.setIcon(UI.PixmapCache.getIcon("begline"))
+        self.endlineButton.setIcon(UI.PixmapCache.getIcon("endline"))
         self.wordboundButton.setIcon(
-            UI.PixmapCache.getIcon("wordboundary.png"))
+            UI.PixmapCache.getIcon("wordboundary"))
         self.nonwordboundButton.setIcon(
-            UI.PixmapCache.getIcon("nonwordboundary.png"))
+            UI.PixmapCache.getIcon("nonwordboundary"))
         self.poslookaheadButton.setIcon(
-            UI.PixmapCache.getIcon("poslookahead.png"))
+            UI.PixmapCache.getIcon("poslookahead"))
         self.neglookaheadButton.setIcon(
-            UI.PixmapCache.getIcon("neglookahead.png"))
+            UI.PixmapCache.getIcon("neglookahead"))
         self.poslookbehindButton.setIcon(
-            UI.PixmapCache.getIcon("poslookbehind.png"))
+            UI.PixmapCache.getIcon("poslookbehind"))
         self.neglookbehindButton.setIcon(
-            UI.PixmapCache.getIcon("neglookbehind.png"))
-        self.undoButton.setIcon(UI.PixmapCache.getIcon("editUndo.png"))
-        self.redoButton.setIcon(UI.PixmapCache.getIcon("editRedo.png"))
+            UI.PixmapCache.getIcon("neglookbehind"))
+        self.undoButton.setIcon(UI.PixmapCache.getIcon("editUndo"))
+        self.redoButton.setIcon(UI.PixmapCache.getIcon("editRedo"))
         
         self.namedGroups = re.compile(r"""\(?P<([^>]+)>""").findall
         
