@@ -9,7 +9,6 @@ Module implementing the setup.py wizard dialog.
 
 
 import os
-import sys
 import datetime
 
 from PyQt5.QtCore import pyqtSlot, Qt, QUrl
@@ -55,9 +54,9 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
         self.__packageRootDirCompleter = E5DirCompleter(self.packageRootEdit)
         self.__sourceDirCompleter = E5DirCompleter(self.sourceDirectoryEdit)
         
-        self.packageRootDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
-        self.packageDirButton.setIcon(UI.PixmapCache.getIcon("open.png"))
-        self.sourceDirectoryButton.setIcon(UI.PixmapCache.getIcon("open.png"))
+        self.packageRootDirButton.setIcon(UI.PixmapCache.getIcon("open"))
+        self.packageDirButton.setIcon(UI.PixmapCache.getIcon("open"))
+        self.sourceDirectoryButton.setIcon(UI.PixmapCache.getIcon("open"))
         
         self.variantComboBox.addItem(self.tr("distutils"), "distutils.core")
         self.variantComboBox.addItem(self.tr("setuptools"), "setuptools")
@@ -253,8 +252,7 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
         
         # now generate the code
         if self.introCheckBox.isChecked():
-            code = "#!/usr/bin/env python{0}{1}".format(
-                sys.version_info[0], os.linesep)
+            code = "#!/usr/bin/env python3{0}".format(os.linesep)
             code += "# -*- coding: utf-8 -*-{0}{0}".format(os.linesep)
         else:
             code = ""
