@@ -79,8 +79,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         
         self.menu = QMenu(self)
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             self.menu.addAction(
                 self.tr('Compile resource'),
@@ -122,8 +121,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         self.menuActions.append(act)
         self.menu.addSeparator()
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             self.menu.addAction(
                 self.tr('New resource...'), self.__newResource)
@@ -151,8 +149,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
 
         self.backMenu = QMenu(self)
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             self.backMenu.addAction(
                 self.tr('Compile all resources'),
@@ -194,8 +191,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         # create the menu for multiple selected files
         self.multiMenu = QMenu(self)
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             act = self.multiMenu.addAction(
                 self.tr('Compile resources'),
@@ -231,8 +227,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
 
         self.dirMenu = QMenu(self)
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             self.dirMenu.addAction(
                 self.tr('Compile all resources'),
@@ -277,8 +272,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         
         self.dirMultiMenu = QMenu(self)
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             self.dirMultiMenu.addAction(
                 self.tr('Compile all resources'),
@@ -357,7 +351,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except Exception:
+        except Exception:           # secok
             pass
         
     def __showContextMenu(self):
@@ -556,7 +550,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
     def __readStdout(self):
         """
         Private slot to handle the readyReadStandardOutput signal of the
-        pyrcc4/pyrcc5/pyside-rcc/pyside2-rcc/rbrcc process.
+        pyrcc5/pyside2-rcc process.
         """
         if self.compileProc is None:
             return
@@ -570,7 +564,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
     def __readStderr(self):
         """
         Private slot to handle the readyReadStandardError signal of the
-        pyrcc4/pyrcc5/pyside-rcc/pyside2-rcc/rbrcc process.
+        pyrcc5/pyside2-rcc/ process.
         """
         if self.compileProc is None:
             return
@@ -616,7 +610,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                                 " was successful."))
                 else:
                     ui.showNotification(
-                        UI.PixmapCache.getPixmap("resourcesCompiler48.png"),
+                        UI.PixmapCache.getPixmap("resourcesCompiler48"),
                         self.tr("Resource Compilation"),
                         self.tr("The compilation of the resource file"
                                 " was successful."))
@@ -637,7 +631,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                         "The compilation of the resource file failed."))
             else:
                 ui.showNotification(
-                    UI.PixmapCache.getPixmap("resourcesCompiler48.png"),
+                    UI.PixmapCache.getPixmap("resourcesCompiler48"),
                     self.tr("Resource Compilation"),
                     self.tr(
                         "The compilation of the resource file failed."))
@@ -656,39 +650,14 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         args = []
         self.buf = ""
         
-        if self.project.getProjectLanguage() in [
-            "Python", "Python2", "Python3"
-        ]:
-            if self.project.getProjectType() in ["Qt4", "Qt4C"]:
-                self.rccCompiler = Utilities.generatePyQtToolPath('pyrcc4')
-                if self.project.getProjectLanguage() in [
-                    "Python", "Python2"
-                ]:
-                    args.append("-py2")
-                else:
-                    args.append("-py3")
-            elif self.project.getProjectType() in ["PyQt5", "PyQt5C"]:
+        if self.project.getProjectLanguage() == "Python3":
+            if self.project.getProjectType() in ["PyQt5", "PyQt5C"]:
                 self.rccCompiler = Utilities.generatePyQtToolPath('pyrcc5')
             elif self.project.getProjectType() in ["E6Plugin"]:
                 self.rccCompiler = Utilities.generatePyQtToolPath('pyrcc5')
-            elif self.project.getProjectType() in ["PySide", "PySideC"]:
-                self.rccCompiler = Utilities.generatePySideToolPath(
-                    'pyside-rcc', "1")
-                if self.project.getProjectLanguage() in [
-                    "Python", "Python2"
-                ]:
-                    args.append("-py2")
-                else:
-                    args.append("-py3")
             elif self.project.getProjectType() in ["PySide2", "PySide2C"]:
                 self.rccCompiler = Utilities.generatePySideToolPath(
-                    'pyside2-rcc', "2")
-                if self.project.getProjectLanguage() in [
-                    "Python", "Python2"
-                ]:
-                    args.append("-py2")
-                else:
-                    args.append("-py3")
+                    'pyside2-rcc')
             else:
                 return None
             defaultParameters = self.project.getDefaultRccCompilerParameters()
@@ -713,13 +682,6 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
             if rccParameters["PathPrefix"] != defaultParameters["PathPrefix"]:
                 args.append("-root")
                 args.append(rccParameters["PathPrefix"])
-        elif self.project.getProjectLanguage() == "Ruby":
-            if self.project.getProjectType() == "Qt4":
-                self.rccCompiler = 'rbrcc'
-                if Utilities.isWindowsPlatform():
-                    self.rccCompiler += '.exe'
-            else:
-                return None
         else:
             return None
         
@@ -729,9 +691,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         fn = os.path.join(self.project.ppath, fn)
         
         dirname, filename = os.path.split(ofn)
-        if self.project.getProjectLanguage() in [
-            "Python", "Python2", "Python3"
-        ]:
+        if self.project.getProjectLanguage() == "Python3":
             self.compiledFile = os.path.join(
                 dirname, self.RCFilenameFormatPython.format(filename))
         elif self.project.getProjectLanguage() == "Ruby":
@@ -909,9 +869,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                 progress.setValue(i)
                 QApplication.processEvents()
                 ifn = os.path.join(self.project.ppath, fn)
-                if self.project.getProjectLanguage() in [
-                    "Python", "Python2", "Python3"
-                ]:
+                if self.project.getProjectLanguage() == "Python3":
                     dirname, filename = os.path.split(os.path.splitext(ifn)[0])
                     ofn = os.path.join(
                         dirname, self.RCFilenameFormatPython.format(filename))
