@@ -327,7 +327,7 @@ class Shell(QsciScintillaCompat):
         self.__setAutoCompletion()
         self.__setCallTips()
         
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
         
         self.incrementalSearchString = ""
         self.incrementalSearchActive = False
@@ -581,6 +581,10 @@ class Shell(QsciScintillaCompat):
         if Preferences.getShell("CallTipsEnabled"):
             self.setCallTipsBackgroundColor(
                 Preferences.getEditorColour("CallTipsBackground"))
+            self.setCallTipsForegroundColor(
+                Preferences.getEditorColour("CallTipsForeground"))
+            self.setCallTipsHighlightColor(
+                Preferences.getEditorColour("CallTipsHighlight"))
             self.setCallTipsVisible(Preferences.getEditor("CallTipsVisible"))
             calltipsStyle = Preferences.getEditor("CallTipsStyle")
             if calltipsStyle == QsciScintilla.CallTipsNoContext:
@@ -992,6 +996,12 @@ class Shell(QsciScintillaCompat):
         QApplication.processEvents()
         
         # Finally process the accumulated text
+        self.__flushQueuedText()
+    
+    def __flushQueuedText(self):
+        """
+        Private slot to flush the accumulated text output.
+        """
         self.__write(self.__queuedText)
         
         self.__queuedText = ''
@@ -1000,7 +1010,7 @@ class Shell(QsciScintillaCompat):
         # little trick to get the cursor position registered within QScintilla
         self.SendScintilla(QsciScintilla.SCI_CHARLEFT)
         self.SendScintilla(QsciScintilla.SCI_CHARRIGHT)
-
+    
     def __write(self, s):
         """
         Private method to display some text without queuing.
@@ -1031,20 +1041,24 @@ class Shell(QsciScintillaCompat):
         """
         self.__write(self.tr("StdErr: {0}").format(s))
         
-    def __raw_input(self, s, echo):
+    def __raw_input(self, prompt, echo):
         """
         Private method to handle raw input.
         
-        @param s prompt to be displayed (string)
-        @param echo Flag indicating echoing of the input (boolean)
+        @param prompt prompt to be displayed
+        @type str
+        @param echo Flag indicating echoing of the input
+        @type bool
         """
-        # Get all text which is still waiting for output
-        QApplication.processEvents()
-        
         self.setFocus()
         self.inRawMode = True
         self.echoInput = echo
-        self.__writeQueued(s)
+        
+        # Get all text which is still waiting for output
+        QApplication.processEvents()
+        self.__flushQueuedText()
+        
+        self.__write(prompt)
         line, col = self.__getEndPos()
         self.setCursorPosition(line, col)
         buf = self.text(line)
