@@ -59,14 +59,17 @@ class SnapshotRegionGrabber(QWidget):
         
         @param mode region grabber mode (SnapshotRegionGrabber.Rectangle or
             SnapshotRegionGrabber.Ellipse)
+        @exception ValueError raised to indicate a bad value for the 'mode'
+            parameter
         """
         super(SnapshotRegionGrabber, self).__init__(
             None,
             Qt.X11BypassWindowManagerHint | Qt.WindowStaysOnTopHint |
             Qt.FramelessWindowHint | Qt.Tool)
         
-        assert mode in [SnapshotRegionGrabber.Rectangle,
-                        SnapshotRegionGrabber.Ellipse]
+        if mode not in [SnapshotRegionGrabber.Rectangle,
+                        SnapshotRegionGrabber.Ellipse]:
+            raise ValueError("Bad value for 'mode' parameter.")
         self.__mode = mode
         
         self.__selection = QRect()
