@@ -60,9 +60,9 @@ class TaskViewer(QTreeWidget):
             ["", "", self.tr("Summary"), self.tr("Filename"),
              self.tr("Line"), ""])
         self.__headerItem.setIcon(
-            0, UI.PixmapCache.getIcon("taskCompleted.png"))
+            0, UI.PixmapCache.getIcon("taskCompleted"))
         self.__headerItem.setIcon(
-            1, UI.PixmapCache.getIcon("taskPriority.png"))
+            1, UI.PixmapCache.getIcon("taskPriority"))
         self.setHeaderItem(self.__headerItem)
         
         self.header().setSortIndicator(2, Qt.AscendingOrder)
@@ -168,7 +168,7 @@ class TaskViewer(QTreeWidget):
         self.customContextMenuRequested.connect(self.__showContextMenu)
         self.itemActivated.connect(self.__taskItemActivated)
         
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
         
         self.__generateTopLevelItems()
     
