@@ -106,11 +106,11 @@ class DownloadManager(QDialog, Ui_DownloadManager):
             itm = self.__downloads[row]
             if itm.downloadedSuccessfully():
                 menu.addAction(
-                    UI.PixmapCache.getIcon("open.png"),
+                    UI.PixmapCache.getIcon("open"),
                     self.tr("Open"), self.__contextMenuOpen)
             elif itm.downloading():
                 menu.addAction(
-                    UI.PixmapCache.getIcon("stopLoading.png"),
+                    UI.PixmapCache.getIcon("stopLoading"),
                     self.tr("Cancel"), self.__contextMenuCancel)
                 menu.addSeparator()
             menu.addAction(
@@ -386,14 +386,15 @@ class DownloadManager(QDialog, Ui_DownloadManager):
             (DownloadManager.RemoveExit, DownloadManager.RemoveNever,
              DownloadManager.RemoveSuccessFullDownload)
         """
-        assert policy in (DownloadManager.RemoveExit,
-                          DownloadManager.RemoveNever,
-                          DownloadManager.RemoveSuccessFullDownload)
-        
-        if policy == self.removePolicy():
-            return
-        
-        Preferences.setWebBrowser("DownloadManagerRemovePolicy", self.policy)
+        if policy in (DownloadManager.RemoveExit,
+                      DownloadManager.RemoveNever,
+                      DownloadManager.RemoveSuccessFullDownload):
+            
+            if policy == self.removePolicy():
+                return
+            
+            Preferences.setWebBrowser("DownloadManagerRemovePolicy",
+                                      self.policy)
     
     def save(self):
         """
@@ -499,7 +500,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
             if success and e5App().activeWindow() is not self:
                 if WebBrowserWindow.notificationsEnabled():
                     WebBrowserWindow.showNotification(
-                        UI.PixmapCache.getPixmap("downloads48.png"),
+                        UI.PixmapCache.getPixmap("downloads48"),
                         self.tr("Downloads finished"),
                         self.tr("All files have been downloaded.")
                     )
