@@ -164,7 +164,7 @@ class SafeBrowsingAPIClient(QObject):
         Public method to find full hashes matching hash prefixes.
         
         @param prefixes list of hash prefixes to find
-        @type list of str (Python 2) or list of bytes (Python 3)
+        @type list of bytes
         @param clientState dictionary of client states with keys like
             (threatType, platformType, threatEntryType)
         @type dict
