@@ -130,12 +130,13 @@ class WebBrowserPage(QWebEnginePage):
                 return False
         
         # GreaseMonkey
-        if PYQT_WEBENGINE_VERSION >= 0x50e00:       # PyQtWebEngine >= 5.14.0
+        try:
+            # PyQtWebEngine >= 5.14.0
             navigationType = type_ in [
                 QWebEnginePage.NavigationTypeLinkClicked,
                 QWebEnginePage.NavigationTypeRedirect
             ]
-        else:
+        except AttributeError:
             navigationType = type_ == QWebEnginePage.NavigationTypeLinkClicked
         if navigationType and url.toString().endswith(".user.js"):
             WebBrowserWindow.greaseMonkeyManager().downloadScript(url)
